package com.miaxis.app.controller.exam;

import com.miaxis.common.constant.Constants;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.core.domain.Response;
import com.miaxis.common.core.page.ResponsePageInfo;
import com.miaxis.exam.domain.ExamInfo;
import com.miaxis.exam.service.IExamInfoService;
import com.miaxis.exam.vo.ExamInfoCityVo;
import com.miaxis.exam.vo.ExamInfoProviceVo;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 【考场信息】Controller
 *
 * @author miaxis
 * @date 2023-03-20
 */
@RestController
@RequestMapping(Constants.STUDENT_PREFIX+"/exam/info")
@Api(tags={"【APP-考场信息】"})
public class ExamInfoController extends BaseController{
    @Autowired
    private IExamInfoService examInfoService;

    /**
     * 查询考场信息列表
     */
    @GetMapping("/list")
    @ApiOperation("查询考场信息列表")
        @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<ExamInfo> list(@ModelAttribute ExamInfo examInfo){
        startPage();
        List<ExamInfo> list = examInfoService.selectExamInfoList(examInfo);
        return toResponsePageInfo(list);
    }

    /**
     * 获取考场信息详细信息
     */
    @GetMapping(value = "/{id}")
    @ApiOperation("获取考场信息详细信息")
    public Response<ExamInfo> getInfo(
            @ApiParam(name = "id", value = "考场信息参数", required = true)
            @PathVariable("id") Long id
    ){
        return Response.success(examInfoService.getById(id));
    }


    /**
     * 获取考场省份
     */
    @GetMapping("/getProvice")
    @ApiOperation("获取考场省份")
    public Response<List<ExamInfoProviceVo>> getProvice(){
        List<ExamInfoProviceVo> list = examInfoService.getProvice();
        return Response.success(list);
    }


    /**
     * 根据省份ID获取考场城市
     */
    @GetMapping(value = "/city/{proviceId}")
    @ApiOperation("根据省份ID获取考场城市")
    public Response<List<ExamInfoCityVo>> getCity(
            @ApiParam(name = "proviceId", value = "考场信息参数", required = true)
            @PathVariable("proviceId") String proviceId
    ){
        return Response.success(examInfoService.getCity(proviceId));
    }




}
