package com.miaxis.pc.controller;

import com.miaxis.common.annotation.Log;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.core.domain.Response;
import com.miaxis.common.core.page.ResponsePageInfo;
import com.miaxis.common.enums.BusinessTypeEnum;
import com.miaxis.common.utils.poi.ExcelUtil;
import com.miaxis.exam.domain.ExamInfo;
import com.miaxis.exam.service.IExamInfoService;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;
import java.util.List;

/**
 * 【考场信息】Controller
 *
 * @author miaxis
 * @date 2023-03-20
 */
@RestController
@RequestMapping("/exam/info")
@Api(tags={"【PC-考场信息】"})
public class PcExamInfoController extends BaseController{
    @Autowired
    private IExamInfoService examInfoService;

    /**
     * 查询考场信息列表
     */
    @GetMapping("/list")
    @ApiOperation("查询考场信息列表")
        @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<ExamInfo> list(@ModelAttribute ExamInfo examInfo){
        startPage();
        List<ExamInfo> list = examInfoService.selectExamInfoList(examInfo);
        return toResponsePageInfo(list);
    }
    
    /**
     * 导出考场信息列表
     */
    @Log(title = "考场信息", businessType = BusinessTypeEnum.EXPORT)
    @GetMapping("/export")
    @ApiOperation("导出考场信息列表Excel")
    public Response<String> export(@ModelAttribute ExamInfo examInfo){
        List<ExamInfo> list = examInfoService.selectExamInfoList(examInfo);
        ExcelUtil<ExamInfo> util = new ExcelUtil<ExamInfo>(ExamInfo.class);
        return util.exportExcel(list, "info");
    }

    /**
     * 获取考场信息详细信息
     */
    @GetMapping(value = "/{id}")
    @ApiOperation("获取考场信息详细信息")
    public Response<ExamInfo> getInfo(
            @ApiParam(name = "id", value = "考场信息参数", required = true)
            @PathVariable("id") Long id
    ){
        return Response.success(examInfoService.getById(id));
    }

    /**
     * 新增考场信息
     */
    @Log(title = "考场信息", businessType = BusinessTypeEnum.INSERT)
    @PostMapping
    @ApiOperation("新增考场信息")
    public Response<Integer> add(@RequestBody ExamInfo examInfo){
        return toResponse(examInfoService.save(examInfo) ? 1 : 0);
    }

    /**
     * 修改考场信息
     */
    @Log(title = "考场信息", businessType = BusinessTypeEnum.UPDATE)
    @PutMapping
    @ApiOperation("修改考场信息")
    public Response<Integer> edit(@RequestBody ExamInfo examInfo){
        return toResponse(examInfoService.updateById(examInfo) ? 1 : 0);
    }

    /**
     * 删除考场信息
     */
    @Log(title = "考场信息", businessType = BusinessTypeEnum.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除考场信息")
    public  Response<Integer> remove(
            @ApiParam(name = "ids", value = "考场信息ids参数", required = true)
            @PathVariable Long[] ids
    ){
        return toResponse(examInfoService.removeByIds(Arrays.asList(ids)) ? 1 : 0);
    }
}
