package com.miaxis.pc.controller;

import com.miaxis.common.annotation.Log;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.core.domain.Response;
import com.miaxis.common.core.page.ResponsePageInfo;
import com.miaxis.common.enums.BusinessTypeEnum;
import com.miaxis.common.utils.poi.ExcelUtil;
import com.miaxis.vip.domain.VipExamVideo;
import com.miaxis.vip.service.IVipExamVideoService;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;
import java.util.List;

/**
 * 【考场视频】Controller
 *
 * @author miaxis
 * @date 2023-03-20
 */
@RestController
@RequestMapping("/vip/video")
@Api(tags={"【PC-考场视频】"})
public class PcVipExamVideoController extends BaseController{
    @Autowired
    private IVipExamVideoService vipExamVideoService;

    /**
     * 查询考场视频列表
     */
    @PreAuthorize("@ss.hasPermi('vip:video:list')")
    @GetMapping("/list")
    @ApiOperation("查询考场视频列表")
        @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<VipExamVideo> list(@ModelAttribute VipExamVideo vipExamVideo){
        startPage();
        List<VipExamVideo> list = vipExamVideoService.selectVipExamVideoList(vipExamVideo);
        return toResponsePageInfo(list);
    }
    
    /**
     * 导出考场视频列表
     */
    @PreAuthorize("@ss.hasPermi('vip:video:export')")
    @Log(title = "考场视频", businessType = BusinessTypeEnum.EXPORT)
    @GetMapping("/export")
    @ApiOperation("导出考场视频列表Excel")
    public Response<String> export(@ModelAttribute VipExamVideo vipExamVideo){
        List<VipExamVideo> list = vipExamVideoService.selectVipExamVideoList(vipExamVideo);
        ExcelUtil<VipExamVideo> util = new ExcelUtil<VipExamVideo>(VipExamVideo.class);
        return util.exportExcel(list, "video");
    }

    /**
     * 获取考场视频详细信息
     */
    @PreAuthorize("@ss.hasPermi('vip:video:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation("获取考场视频详细信息")
    public Response<VipExamVideo> getInfo(
            @ApiParam(name = "id", value = "考场视频参数", required = true)
            @PathVariable("id") Long id
    ){
        return Response.success(vipExamVideoService.getById(id));
    }

    /**
     * 新增考场视频
     */
    @PreAuthorize("@ss.hasPermi('vip:video:add')")
    @Log(title = "考场视频", businessType = BusinessTypeEnum.INSERT)
    @PostMapping
    @ApiOperation("新增考场视频")
    public Response<Integer> add(@RequestBody VipExamVideo vipExamVideo){
        return toResponse(vipExamVideoService.save(vipExamVideo) ? 1 : 0);
    }

    /**
     * 修改考场视频
     */
    @PreAuthorize("@ss.hasPermi('vip:video:edit')")
    @Log(title = "考场视频", businessType = BusinessTypeEnum.UPDATE)
    @PutMapping
    @ApiOperation("修改考场视频")
    public Response<Integer> edit(@RequestBody VipExamVideo vipExamVideo){
        return toResponse(vipExamVideoService.updateById(vipExamVideo) ? 1 : 0);
    }

    /**
     * 删除考场视频
     */
    @PreAuthorize("@ss.hasPermi('vip:video:remove')")
    @Log(title = "考场视频", businessType = BusinessTypeEnum.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除考场视频")
    public  Response<Integer> remove(
            @ApiParam(name = "ids", value = "考场视频ids参数", required = true)
            @PathVariable Long[] ids
    ){
        return toResponse(vipExamVideoService.removeByIds(Arrays.asList(ids)) ? 1 : 0);
    }
}
