package com.miaxis.pc.controller;

import com.miaxis.common.annotation.Log;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.core.domain.Response;
import com.miaxis.common.core.page.ResponsePageInfo;
import com.miaxis.common.enums.BusinessTypeEnum;
import com.miaxis.common.utils.poi.ExcelUtil;
import com.miaxis.vip.domain.VipUserExam;
import com.miaxis.vip.service.IVipUserExamService;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;
import java.util.List;

/**
 * 【考场会员】Controller
 *
 * @author miaxis
 * @date 2023-03-20
 */
@RestController
@RequestMapping("/vip/exam")
@Api(tags={"【PC-考场会员】"})
public class PcVipUserExamController extends BaseController{
    @Autowired
    private IVipUserExamService vipUserExamService;

    /**
     * 查询考场会员列表
     */
    @PreAuthorize("@ss.hasPermi('vip:exam:list')")
    @GetMapping("/list")
    @ApiOperation("查询考场会员列表")
        @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<VipUserExam> list(@ModelAttribute VipUserExam vipUserExam){
        startPage();
        List<VipUserExam> list = vipUserExamService.selectVipUserExamList(vipUserExam);
        return toResponsePageInfo(list);
    }
    
    /**
     * 导出考场会员列表
     */
    @PreAuthorize("@ss.hasPermi('vip:exam:export')")
    @Log(title = "考场会员", businessType = BusinessTypeEnum.EXPORT)
    @GetMapping("/export")
    @ApiOperation("导出考场会员列表Excel")
    public Response<String> export(@ModelAttribute VipUserExam vipUserExam){
        List<VipUserExam> list = vipUserExamService.selectVipUserExamList(vipUserExam);
        ExcelUtil<VipUserExam> util = new ExcelUtil<VipUserExam>(VipUserExam.class);
        return util.exportExcel(list, "exam");
    }

    /**
     * 获取考场会员详细信息
     */
    @PreAuthorize("@ss.hasPermi('vip:exam:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation("获取考场会员详细信息")
    public Response<VipUserExam> getInfo(
            @ApiParam(name = "id", value = "考场会员参数", required = true)
            @PathVariable("id") Long id
    ){
        return Response.success(vipUserExamService.getById(id));
    }

    /**
     * 新增考场会员
     */
    @PreAuthorize("@ss.hasPermi('vip:exam:add')")
    @Log(title = "考场会员", businessType = BusinessTypeEnum.INSERT)
    @PostMapping
    @ApiOperation("新增考场会员")
    public Response<Integer> add(@RequestBody VipUserExam vipUserExam){
        return toResponse(vipUserExamService.save(vipUserExam) ? 1 : 0);
    }

    /**
     * 修改考场会员
     */
    @PreAuthorize("@ss.hasPermi('vip:exam:edit')")
    @Log(title = "考场会员", businessType = BusinessTypeEnum.UPDATE)
    @PutMapping
    @ApiOperation("修改考场会员")
    public Response<Integer> edit(@RequestBody VipUserExam vipUserExam){
        return toResponse(vipUserExamService.updateById(vipUserExam) ? 1 : 0);
    }

    /**
     * 删除考场会员
     */
    @PreAuthorize("@ss.hasPermi('vip:exam:remove')")
    @Log(title = "考场会员", businessType = BusinessTypeEnum.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除考场会员")
    public  Response<Integer> remove(
            @ApiParam(name = "ids", value = "考场会员ids参数", required = true)
            @PathVariable Long[] ids
    ){
        return toResponse(vipUserExamService.removeByIds(Arrays.asList(ids)) ? 1 : 0);
    }
}
